"""
Tests of the Spike class
"""

try:
    import unittest2 as unittest
except ImportError:
    import unittest

from neo.core.spike import Spike

class TestSpike(unittest.TestCase):
    pass


if __name__ == "__main__":
    unittest.main()
